.. currentmodule:: sardana.macroserver.msenvmanager

:mod:`~sardana.macroserver.msenvmanager`
=========================================

.. automodule:: sardana.macroserver.msenvmanager

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`EnvironmentManager`

EnvironmentManager
--------------------

.. inheritance-diagram:: EnvironmentManager
    :parts: 1
    
.. autoclass:: EnvironmentManager
    :show-inheritance:
